@@ -2,6 +2,14 @@
 #include <Rdefines.h>
 #include <ctype.h>
 
+static int is_ascii_digit(int c) {
+    return(isdigit(c) && isascii(c));
+}
+
+static int is_ascii_punct(int c) {
+    return(ispunct(c) && isascii(c));
+}
+
 SEXP _tm_remove_chars(SEXP x, SEXP which) {
     SEXP y, this;
     int n, i, w;
@@ -9,13 +17,13 @@ SEXP _tm_remove_chars(SEXP x, SEXP which) {
     char c, *t, *p;
     cetype_t e;
 
-    int (*test) () = ispunct;
+    int (*test) () = is_ascii_punct;
 
     if(LENGTH(which) > 0) {
 	PROTECT(this = AS_INTEGER(which));
 	w = INTEGER(this)[0];
 	if(w == 1)
-	    test = isdigit;
+	    test = is_ascii_digit;
 	UNPROTECT(1);
     }
 
@@ -33,7 +41,8 @@ SEXP _tm_remove_chars(SEXP x, SEXP which) {
 	s = CHAR(this);
 	t = p = (char *) R_alloc(strlen(s) + 1, sizeof(char));
 	while((c = *s++) != '\0') {
-	    if(!test(c)) *t++ = c;
+	    if(!test(c))
+		*t++ = c;
 	}
 	*t = '\0';
 	SET_STRING_ELT(y, i, mkCharCE(p, e));
